@@ -1,8 +1,8 @@
+from contextlib import asynccontextmanager
 from io import BytesIO
 from pathlib import Path
 from textwrap import dedent
 import asyncio
-import os
 import sys
 import tarfile
 
@@ -23,36 +23,41 @@ def tar_from_directory(directory):
     return fileobj
 
 
-@pytest_asyncio.fixture(scope='function')
+@pytest_asyncio.fixture(scope="function")
 async def lintsonschema(docker):
     tag = "bowtie-integration-tests/lintsonschema"
     await docker.images.build(
         fileobj=tar_from_directory(FAUXMPLEMENTATIONS / "lintsonschema"),
         encoding="utf-8",
-        tag=tag
+        tag=tag,
     )
     yield tag
     await docker.images.delete(name=tag)
 
 
-@pytest.mark.asyncio
-async def test_lint(lintsonschema):
-
+@asynccontextmanager
+async def bowtie(*args):
     proc = await asyncio.create_subprocess_exec(
-        sys.executable, "-m", "bowtie", "run",
-        "-i", lintsonschema,
+        sys.executable, "-m", "bowtie", "run", *args,
         stdin=asyncio.subprocess.PIPE,
         stdout=asyncio.subprocess.PIPE,
         stderr=asyncio.subprocess.PIPE,
     )
 
-    stdout, stderr = await proc.communicate(
-        dedent(
+    async def _send(stdin):
+        result = await proc.communicate(dedent(stdin).lstrip("\n").encode())
+        return proc.returncode, *result
+    yield _send
+
+
+@pytest.mark.asyncio
+async def test_lint(lintsonschema):
+    async with bowtie("-i", lintsonschema) as send:
+        returncode, stdout, stderr = await send(
             """
             {"description": "a test case", "schema": {}, "tests": [{"description": "a test", "instance": {}}] }
-            """
-        ).lstrip("\n").encode("utf-8")
-    )
+            """,  # noqa: E501
+        )
 
     assert stderr.decode() == ""
-    assert proc.returncode == 0
+    assert returncode == 0
